@@ -222,7 +222,7 @@ def send_mail(subject, verbose):
     {number_restart} operation affin de le relancer ont toutes échouées
     
     Information système : 
-    CPU Temp = {os.system(cpu_temp)}
+    CPU Temp = {cpu_temp}°C
     CPU Usage = {os.system(cpu_usage)}
     From Auto_Check_service Python Bot"""
 
